[![Documentation Status](https://readthedocs.org/projects/h5preserve/badge/?version=latest)](http://h5preserve.readthedocs.org/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/aragilar/h5preserve.svg?branch=master)](https://travis-ci.org/aragilar/h5preserve)
[![Coverage Status](https://codecov.io/github/aragilar/h5preserve/coverage.svg?branch=master)](https://codecov.io/github/aragilar/h5preserve?branch=master)
[![Version](https://img.shields.io/pypi/v/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![License](https://img.shields.io/pypi/l/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![Wheel](https://img.shields.io/pypi/wheel/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![Format](https://img.shields.io/pypi/format/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![Supported versions](https://img.shields.io/pypi/pyversions/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![Supported implemntations](https://img.shields.io/pypi/implementation/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)
[![PyPI](https://img.shields.io/pypi/status/h5preserve.svg)](https://pypi.python.org/pypi/h5preserve/)

h5preserve is a thin wrapper around [h5py](http://www.h5py.org/), inspired by
[camel](http://eev.ee/blog/2015/10/15/dont-use-pickle-use-camel/).

It can be installed via pip, but note that h5py requires a C compiler and the
hdf5 library.

Bug reports and suggestions should be filed at
[https://github.com/aragilar/h5preserve/issues](https://github.com/aragilar/h5preserve/issues).
